The term_vec Module — pysimsearch v0.30 documentation

### Navigation

- index
- modules |
- previous |
- pysimsearch v0.30 documentation »

# The `term_vec` Module

Term-vector operations

`pysimsearch.term_vec.` `dot_product`(v1, v2)

  Returns dot product of two term vectors

`pysimsearch.term_vec.` `l2_norm`(v)

  Returns L2 norm of term vector v

`pysimsearch.term_vec.` `mag_intersect`(A, B)

  Returns magnitude of multiset-intersection of A and B

`pysimsearch.term_vec.` `mag_union`(A, B)

  Returns magnitude of multiset-union of A and B

`pysimsearch.term_vec.` `magnitude`(v)

  Returns L2 norm of term vector v (identical to l2_norm())

### Navigation

- index
- modules |
- previous |
- pysimsearch v0.30 documentation »